netapp_ontap.models.application_rpo_remote API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.application_rpo_remote`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ApplicationRpoRemoteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ApplicationRpoRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `description: str GET`

    A detailed description of the remote RPO.

  `name: str GET`

    The remote RPO of the application. A remote RPO of zero indicates that the application is synchronously replicated to another cluster.

    Valid choices:

    - 6_hourly
    - 15_minutely
    - hourly
    - none
    - zero